# coding: utf-8

"""
    Regula Face SDK Web API

    <a href=\"https://regulaforensics.com/products/face-recognition-sdk/  \" target=\"_blank\">Regula Face SDK</a> is a cross-platform biometric verification solution for a digital identity verification process and image quality assurance. The SDK enables convenient and reliable face capture on the client side (mobile, web, and desktop) and further processing on the client or server side.   The Face SDK includes the following features:  * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-detection\" target=\"_blank\">Face detection and image quality assessment</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-comparison-11\" target=\"_blank\">Face match (1:1)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-identification-1n\" target=\"_blank\">Face search (1:N)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#liveness-assessment\" target=\"_blank\">Liveness detection</a>  Here is the <a href=\"https://github.com/regulaforensics/FaceSDK-web-openapi  \" target=\"_blank\">OpenAPI specification on GitHub</a>.   ### Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 7.2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from regula.facesdk.webclient.gen.api_client import ApiClient
from regula.facesdk.webclient.gen.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class Liveness20Api(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete_liveness_transaction(self, transaction_id, tag, **kwargs):  # noqa: E501
        """delete liveness transaction  # noqa: E501

        This endpoint deletes a liveness transaction based on either the specified `tag` or `transactionId`. At least one of the parameters must be provided for the operation to be valid.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_liveness_transaction(transaction_id, tag, async_req=True)
        >>> result = thread.get()

        :param transaction_id: ID of the current liveness transaction. (required)
        :type transaction_id: str
        :param tag: A unique tag associated with a liveness transaction session. Used to identify and delete the corresponding transaction. (required)
        :type tag: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_liveness_transaction_with_http_info(transaction_id, tag, **kwargs)  # noqa: E501

    def delete_liveness_transaction_with_http_info(self, transaction_id, tag, **kwargs):  # noqa: E501
        """delete liveness transaction  # noqa: E501

        This endpoint deletes a liveness transaction based on either the specified `tag` or `transactionId`. At least one of the parameters must be provided for the operation to be valid.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_liveness_transaction_with_http_info(transaction_id, tag, async_req=True)
        >>> result = thread.get()

        :param transaction_id: ID of the current liveness transaction. (required)
        :type transaction_id: str
        :param tag: A unique tag associated with a liveness transaction session. Used to identify and delete the corresponding transaction. (required)
        :type tag: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = [
            'transaction_id',
            'tag',
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_liveness_transaction" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'transaction_id' is set
        if self.api_client.client_side_validation and ('transaction_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['transaction_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `transaction_id` when calling `delete_liveness_transaction`")  # noqa: E501
        # verify the required parameter 'tag' is set
        if self.api_client.client_side_validation and ('tag' not in local_var_params or  # noqa: E501
                                                        local_var_params['tag'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `tag` when calling `delete_liveness_transaction`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'transaction_id' in local_var_params and local_var_params['transaction_id'] is not None:  # noqa: E501
            query_params.append(('transactionId', local_var_params['transaction_id']))  # noqa: E501
        if 'tag' in local_var_params and local_var_params['tag'] is not None:  # noqa: E501
            query_params.append(('tag', local_var_params['tag']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/liveness', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def get_liveness_transaction_info(self, transaction_id, **kwargs):  # noqa: E501
        """liveness check  # noqa: E501

        To verify the presence of a real person in front of a camera, use the GET `/api/v2/liveness` endpoint. When starting, you can specify `tag` which all attempts to read liveness will be bound to. If left unspecified, the application automatically generates one. The calling application returns `tag` and `transactionId`. One session may include many transactions, and from a transaction ID it is clear which session it belongs to.  When specifying `tag`, note that only Latin uppercase and lowercase letters, digits, and symbols `-` and `_` are allowed. The maximum supported number of characters is 127.  The metadata (device model, screen data, frame size, app ID and version, OS version, platform, SDK version, etc.), a person's selfie and video of the liveness detection session are stored on the backend at: `faceapi-session/year={year}/month={month}/day={day}/hour={hour}/minute={minute}/{tag}/transactionId`  By default, liveness checks operate with eventual consistency. This means that when you submit a request and receive a response, the associated data (like the selfie and session video) may be saved after the response is sent. If this doesn't meet your requirements, you can switch to strong consistency; refer to the [Architecture page](https://docs.regulaforensics.com/develop/face-sdk/overview/architecture/#consistency-models) for details.  To access the liveness transaction data, use GET `/api/v2/liveness?transactionId={transactionId}`.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_liveness_transaction_info(transaction_id, async_req=True)
        >>> result = thread.get()

        :param transaction_id: ID of the current liveness transaction. (required)
        :type transaction_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: TransactionInfo
        """
        kwargs['_return_http_data_only'] = True
        return self.get_liveness_transaction_info_with_http_info(transaction_id, **kwargs)  # noqa: E501

    def get_liveness_transaction_info_with_http_info(self, transaction_id, **kwargs):  # noqa: E501
        """liveness check  # noqa: E501

        To verify the presence of a real person in front of a camera, use the GET `/api/v2/liveness` endpoint. When starting, you can specify `tag` which all attempts to read liveness will be bound to. If left unspecified, the application automatically generates one. The calling application returns `tag` and `transactionId`. One session may include many transactions, and from a transaction ID it is clear which session it belongs to.  When specifying `tag`, note that only Latin uppercase and lowercase letters, digits, and symbols `-` and `_` are allowed. The maximum supported number of characters is 127.  The metadata (device model, screen data, frame size, app ID and version, OS version, platform, SDK version, etc.), a person's selfie and video of the liveness detection session are stored on the backend at: `faceapi-session/year={year}/month={month}/day={day}/hour={hour}/minute={minute}/{tag}/transactionId`  By default, liveness checks operate with eventual consistency. This means that when you submit a request and receive a response, the associated data (like the selfie and session video) may be saved after the response is sent. If this doesn't meet your requirements, you can switch to strong consistency; refer to the [Architecture page](https://docs.regulaforensics.com/develop/face-sdk/overview/architecture/#consistency-models) for details.  To access the liveness transaction data, use GET `/api/v2/liveness?transactionId={transactionId}`.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_liveness_transaction_info_with_http_info(transaction_id, async_req=True)
        >>> result = thread.get()

        :param transaction_id: ID of the current liveness transaction. (required)
        :type transaction_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(TransactionInfo, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'transaction_id',
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_liveness_transaction_info" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'transaction_id' is set
        if self.api_client.client_side_validation and ('transaction_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['transaction_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `transaction_id` when calling `get_liveness_transaction_info`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'transaction_id' in local_var_params and local_var_params['transaction_id'] is not None:  # noqa: E501
            query_params.append(('transactionId', local_var_params['transaction_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/liveness', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TransactionInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))



# coding: utf-8

"""
    Regula Face SDK Web API

    <a href=\"https://regulaforensics.com/products/face-recognition-sdk/  \" target=\"_blank\">Regula Face SDK</a> is a cross-platform biometric verification solution for a digital identity verification process and image quality assurance. The SDK enables convenient and reliable face capture on the client side (mobile, web, and desktop) and further processing on the client or server side.   The Face SDK includes the following features:  * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-detection\" target=\"_blank\">Face detection and image quality assessment</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-comparison-11\" target=\"_blank\">Face match (1:1)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-identification-1n\" target=\"_blank\">Face search (1:N)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#liveness-assessment\" target=\"_blank\">Liveness detection</a>  Here is the <a href=\"https://github.com/regulaforensics/FaceSDK-web-openapi  \" target=\"_blank\">OpenAPI specification on GitHub</a>.   ### Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 7.2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from regula.facesdk.webclient.gen.configuration import Configuration


class MatchImageResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'first_index': 'int',
        'first_face_index': 'float',
        'first': 'ImageSource',
        'second_index': 'int',
        'second_face_index': 'float',
        'second': 'ImageSource',
        'score': 'float',
        'similarity': 'float',
    }

    attribute_map = {
        'first_index': 'firstIndex',
        'first_face_index': 'firstFaceIndex',
        'first': 'first',
        'second_index': 'secondIndex',
        'second_face_index': 'secondFaceIndex',
        'second': 'second',
        'score': 'score',
        'similarity': 'similarity',
    }

    def __init__(self, first_index=None, first_face_index=None, first=None, second_index=None, second_face_index=None, second=None, score=None, similarity=None, local_vars_configuration=None):  # noqa: E501
        """MatchImageResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._first_index = None
        self._first_face_index = None
        self._first = None
        self._second_index = None
        self._second_face_index = None
        self._second = None
        self._score = None
        self._similarity = None
        self.discriminator = None

        self.first_index = first_index
        if first_face_index is not None:
            self.first_face_index = first_face_index
        if first is not None:
            self.first = first
        self.second_index = second_index
        if second_face_index is not None:
            self.second_face_index = second_face_index
        if second is not None:
            self.second = second
        if score is not None:
            self.score = score
        if similarity is not None:
            self.similarity = similarity

    @property
    def first_index(self):
        """Gets the first_index of this MatchImageResult.  # noqa: E501

        The image index number. Can be given; if not given, the index numbers are set automatically starting from `0`. All index numbers must be whole and unique—not repeated.  # noqa: E501

        :return: The first_index of this MatchImageResult.  # noqa: E501
        :rtype: int
        """
        return self._first_index

    @first_index.setter
    def first_index(self, first_index):
        """Sets the first_index of this MatchImageResult.

        The image index number. Can be given; if not given, the index numbers are set automatically starting from `0`. All index numbers must be whole and unique—not repeated.  # noqa: E501

        :param first_index: The first_index of this MatchImageResult.  # noqa: E501
        :type first_index: int
        """
        if self.local_vars_configuration.client_side_validation and first_index is None:  # noqa: E501
            raise ValueError("Invalid value for `first_index`, must not be `None`")  # noqa: E501

        self._first_index = first_index

    @property
    def first_face_index(self):
        """Gets the first_face_index of this MatchImageResult.  # noqa: E501

        The detected face index number.  # noqa: E501

        :return: The first_face_index of this MatchImageResult.  # noqa: E501
        :rtype: float
        """
        return self._first_face_index

    @first_face_index.setter
    def first_face_index(self, first_face_index):
        """Sets the first_face_index of this MatchImageResult.

        The detected face index number.  # noqa: E501

        :param first_face_index: The first_face_index of this MatchImageResult.  # noqa: E501
        :type first_face_index: float
        """

        self._first_face_index = first_face_index

    @property
    def first(self):
        """Gets the first of this MatchImageResult.  # noqa: E501


        :return: The first of this MatchImageResult.  # noqa: E501
        :rtype: ImageSource
        """
        return self._first

    @first.setter
    def first(self, first):
        """Sets the first of this MatchImageResult.


        :param first: The first of this MatchImageResult.  # noqa: E501
        :type first: ImageSource
        """

        self._first = first

    @property
    def second_index(self):
        """Gets the second_index of this MatchImageResult.  # noqa: E501

        The image index number. Can be given; if not given, the index numbers are set automatically starting from `0`. All index numbers must be whole and unique—not repeated.  # noqa: E501

        :return: The second_index of this MatchImageResult.  # noqa: E501
        :rtype: int
        """
        return self._second_index

    @second_index.setter
    def second_index(self, second_index):
        """Sets the second_index of this MatchImageResult.

        The image index number. Can be given; if not given, the index numbers are set automatically starting from `0`. All index numbers must be whole and unique—not repeated.  # noqa: E501

        :param second_index: The second_index of this MatchImageResult.  # noqa: E501
        :type second_index: int
        """
        if self.local_vars_configuration.client_side_validation and second_index is None:  # noqa: E501
            raise ValueError("Invalid value for `second_index`, must not be `None`")  # noqa: E501

        self._second_index = second_index

    @property
    def second_face_index(self):
        """Gets the second_face_index of this MatchImageResult.  # noqa: E501

        The detected face index number.  # noqa: E501

        :return: The second_face_index of this MatchImageResult.  # noqa: E501
        :rtype: float
        """
        return self._second_face_index

    @second_face_index.setter
    def second_face_index(self, second_face_index):
        """Sets the second_face_index of this MatchImageResult.

        The detected face index number.  # noqa: E501

        :param second_face_index: The second_face_index of this MatchImageResult.  # noqa: E501
        :type second_face_index: float
        """

        self._second_face_index = second_face_index

    @property
    def second(self):
        """Gets the second of this MatchImageResult.  # noqa: E501


        :return: The second of this MatchImageResult.  # noqa: E501
        :rtype: ImageSource
        """
        return self._second

    @second.setter
    def second(self, second):
        """Sets the second of this MatchImageResult.


        :param second: The second of this MatchImageResult.  # noqa: E501
        :type second: ImageSource
        """

        self._second = second

    @property
    def score(self):
        """Gets the score of this MatchImageResult.  # noqa: E501

        A dimensionless number that shows how similar the compared faces are. 0—absolutely identical faces.  # noqa: E501

        :return: The score of this MatchImageResult.  # noqa: E501
        :rtype: float
        """
        return self._score

    @score.setter
    def score(self, score):
        """Sets the score of this MatchImageResult.

        A dimensionless number that shows how similar the compared faces are. 0—absolutely identical faces.  # noqa: E501

        :param score: The score of this MatchImageResult.  # noqa: E501
        :type score: float
        """

        self._score = score

    @property
    def similarity(self):
        """Gets the similarity of this MatchImageResult.  # noqa: E501

        The detected faces similarity, %. 100%—absolutely identical faces, 0%—absolutely not identical.  # noqa: E501

        :return: The similarity of this MatchImageResult.  # noqa: E501
        :rtype: float
        """
        return self._similarity

    @similarity.setter
    def similarity(self, similarity):
        """Sets the similarity of this MatchImageResult.

        The detected faces similarity, %. 100%—absolutely identical faces, 0%—absolutely not identical.  # noqa: E501

        :param similarity: The similarity of this MatchImageResult.  # noqa: E501
        :type similarity: float
        """

        self._similarity = similarity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MatchImageResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MatchImageResult):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Regula Face SDK Web API

    <a href=\"https://regulaforensics.com/products/face-recognition-sdk/  \" target=\"_blank\">Regula Face SDK</a> is a cross-platform biometric verification solution for a digital identity verification process and image quality assurance. The SDK enables convenient and reliable face capture on the client side (mobile, web, and desktop) and further processing on the client or server side.   The Face SDK includes the following features:  * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-detection\" target=\"_blank\">Face detection and image quality assessment</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-comparison-11\" target=\"_blank\">Face match (1:1)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-identification-1n\" target=\"_blank\">Face search (1:N)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#liveness-assessment\" target=\"_blank\">Liveness detection</a>  Here is the <a href=\"https://github.com/regulaforensics/FaceSDK-web-openapi  \" target=\"_blank\">OpenAPI specification on GitHub</a>.   ### Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 7.2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from regula.facesdk.webclient.gen.configuration import Configuration


class QualityDetail(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'group_id': 'FaceImageQualityGroups',
        'name': 'FaceQualityConfigName',
        'range': '[float]',
        'status': 'FaceImageQualityStatus',
        'value': 'float',
    }

    attribute_map = {
        'group_id': 'groupId',
        'name': 'name',
        'range': 'range',
        'status': 'status',
        'value': 'value',
    }

    def __init__(self, group_id=None, name=None, range=None, status=None, value=None, local_vars_configuration=None):  # noqa: E501
        """QualityDetail - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._group_id = None
        self._name = None
        self._range = None
        self._status = None
        self._value = None
        self.discriminator = None

        if group_id is not None:
            self.group_id = group_id
        if name is not None:
            self.name = name
        if range is not None:
            self.range = range
        if status is not None:
            self.status = status
        if value is not None:
            self.value = value

    @property
    def group_id(self):
        """Gets the group_id of this QualityDetail.  # noqa: E501


        :return: The group_id of this QualityDetail.  # noqa: E501
        :rtype: FaceImageQualityGroups
        """
        return self._group_id

    @group_id.setter
    def group_id(self, group_id):
        """Sets the group_id of this QualityDetail.


        :param group_id: The group_id of this QualityDetail.  # noqa: E501
        :type group_id: FaceImageQualityGroups
        """

        self._group_id = group_id

    @property
    def name(self):
        """Gets the name of this QualityDetail.  # noqa: E501


        :return: The name of this QualityDetail.  # noqa: E501
        :rtype: FaceQualityConfigName
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this QualityDetail.


        :param name: The name of this QualityDetail.  # noqa: E501
        :type name: FaceQualityConfigName
        """

        self._name = name

    @property
    def range(self):
        """Gets the range of this QualityDetail.  # noqa: E501

        The range of set values for this characteristic, see the [Recommended range column](https://docs.regulaforensics.com/develop/face-sdk/web-service/development/usage/face-detection/face-image-quality-check/).  # noqa: E501

        :return: The range of this QualityDetail.  # noqa: E501
        :rtype: [float]
        """
        return self._range

    @range.setter
    def range(self, range):
        """Sets the range of this QualityDetail.

        The range of set values for this characteristic, see the [Recommended range column](https://docs.regulaforensics.com/develop/face-sdk/web-service/development/usage/face-detection/face-image-quality-check/).  # noqa: E501

        :param range: The range of this QualityDetail.  # noqa: E501
        :type range: [float]
        """
        if (self.local_vars_configuration.client_side_validation and
                range is not None and len(range) > 2):
            raise ValueError("Invalid value for `range`, number of items must be less than or equal to `2`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                range is not None and len(range) < 2):
            raise ValueError("Invalid value for `range`, number of items must be greater than or equal to `2`")  # noqa: E501

        self._range = range

    @property
    def status(self):
        """Gets the status of this QualityDetail.  # noqa: E501


        :return: The status of this QualityDetail.  # noqa: E501
        :rtype: FaceImageQualityStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this QualityDetail.


        :param status: The status of this QualityDetail.  # noqa: E501
        :type status: FaceImageQualityStatus
        """

        self._status = status

    @property
    def value(self):
        """Gets the value of this QualityDetail.  # noqa: E501

        The result value for the characteristic, returned in set units.  # noqa: E501

        :return: The value of this QualityDetail.  # noqa: E501
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this QualityDetail.

        The result value for the characteristic, returned in set units.  # noqa: E501

        :param value: The value of this QualityDetail.  # noqa: E501
        :type value: float
        """

        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QualityDetail):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, QualityDetail):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Regula Face SDK Web API

    <a href=\"https://regulaforensics.com/products/face-recognition-sdk/  \" target=\"_blank\">Regula Face SDK</a> is a cross-platform biometric verification solution for a digital identity verification process and image quality assurance. The SDK enables convenient and reliable face capture on the client side (mobile, web, and desktop) and further processing on the client or server side.   The Face SDK includes the following features:  * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-detection\" target=\"_blank\">Face detection and image quality assessment</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-comparison-11\" target=\"_blank\">Face match (1:1)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-identification-1n\" target=\"_blank\">Face search (1:N)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#liveness-assessment\" target=\"_blank\">Liveness detection</a>  Here is the <a href=\"https://github.com/regulaforensics/FaceSDK-web-openapi  \" target=\"_blank\">OpenAPI specification on GitHub</a>.   ### Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 7.2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from regula.facesdk.webclient.gen.configuration import Configuration


class Detection(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'crop': 'str',
        'attributes': 'DetectionAttributes',
        'landmarks': '[[int]]',
        'quality': 'DetectionQuality',
        'roi': 'FaceRectangular',
    }

    attribute_map = {
        'crop': 'crop',
        'attributes': 'attributes',
        'landmarks': 'landmarks',
        'quality': 'quality',
        'roi': 'roi',
    }

    def __init__(self, crop=None, attributes=None, landmarks=None, quality=None, roi=None, local_vars_configuration=None):  # noqa: E501
        """Detection - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._crop = None
        self._attributes = None
        self._landmarks = None
        self._quality = None
        self._roi = None
        self.discriminator = None

        if crop is not None:
            self.crop = crop
        if attributes is not None:
            self.attributes = attributes
        self.landmarks = landmarks
        if quality is not None:
            self.quality = quality
        self.roi = roi

    @property
    def crop(self):
        """Gets the crop of this Detection.  # noqa: E501

        Base64-encoded image.  # noqa: E501

        :return: The crop of this Detection.  # noqa: E501
        :rtype: str
        """
        return self._crop

    @crop.setter
    def crop(self, crop):
        """Sets the crop of this Detection.

        Base64-encoded image.  # noqa: E501

        :param crop: The crop of this Detection.  # noqa: E501
        :type crop: str
        """

        self._crop = crop

    @property
    def attributes(self):
        """Gets the attributes of this Detection.  # noqa: E501


        :return: The attributes of this Detection.  # noqa: E501
        :rtype: DetectionAttributes
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this Detection.


        :param attributes: The attributes of this Detection.  # noqa: E501
        :type attributes: DetectionAttributes
        """

        self._attributes = attributes

    @property
    def landmarks(self):
        """Gets the landmarks of this Detection.  # noqa: E501

        Absolute coordinates (X,Y) of five points of each detected face: left eye, right eye, nose, left point of lips, right point of lips.  # noqa: E501

        :return: The landmarks of this Detection.  # noqa: E501
        :rtype: [[int]]
        """
        return self._landmarks

    @landmarks.setter
    def landmarks(self, landmarks):
        """Sets the landmarks of this Detection.

        Absolute coordinates (X,Y) of five points of each detected face: left eye, right eye, nose, left point of lips, right point of lips.  # noqa: E501

        :param landmarks: The landmarks of this Detection.  # noqa: E501
        :type landmarks: [[int]]
        """
        if self.local_vars_configuration.client_side_validation and landmarks is None:  # noqa: E501
            raise ValueError("Invalid value for `landmarks`, must not be `None`")  # noqa: E501

        self._landmarks = landmarks

    @property
    def quality(self):
        """Gets the quality of this Detection.  # noqa: E501


        :return: The quality of this Detection.  # noqa: E501
        :rtype: DetectionQuality
        """
        return self._quality

    @quality.setter
    def quality(self, quality):
        """Sets the quality of this Detection.


        :param quality: The quality of this Detection.  # noqa: E501
        :type quality: DetectionQuality
        """

        self._quality = quality

    @property
    def roi(self):
        """Gets the roi of this Detection.  # noqa: E501


        :return: The roi of this Detection.  # noqa: E501
        :rtype: FaceRectangular
        """
        return self._roi

    @roi.setter
    def roi(self, roi):
        """Sets the roi of this Detection.


        :param roi: The roi of this Detection.  # noqa: E501
        :type roi: FaceRectangular
        """
        if self.local_vars_configuration.client_side_validation and roi is None:  # noqa: E501
            raise ValueError("Invalid value for `roi`, must not be `None`")  # noqa: E501

        self._roi = roi

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Detection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Detection):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Regula Face SDK Web API

    <a href=\"https://regulaforensics.com/products/face-recognition-sdk/  \" target=\"_blank\">Regula Face SDK</a> is a cross-platform biometric verification solution for a digital identity verification process and image quality assurance. The SDK enables convenient and reliable face capture on the client side (mobile, web, and desktop) and further processing on the client or server side.   The Face SDK includes the following features:  * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-detection\" target=\"_blank\">Face detection and image quality assessment</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-comparison-11\" target=\"_blank\">Face match (1:1)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-identification-1n\" target=\"_blank\">Face search (1:N)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#liveness-assessment\" target=\"_blank\">Liveness detection</a>  Here is the <a href=\"https://github.com/regulaforensics/FaceSDK-web-openapi  \" target=\"_blank\">OpenAPI specification on GitHub</a>.   ### Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 7.2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from regula.facesdk.webclient.gen.configuration import Configuration


class ProcessParam(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'scenario': 'FaceQualityScenarios',
        'only_central_face': 'bool',
        'output_image_params': 'OutputImageParams',
        'quality': 'QualityRequest',
        'attributes': 'ProcessParamAttributes',
    }

    attribute_map = {
        'scenario': 'scenario',
        'only_central_face': 'onlyCentralFace',
        'output_image_params': 'outputImageParams',
        'quality': 'quality',
        'attributes': 'attributes',
    }

    def __init__(self, scenario=None, only_central_face=None, output_image_params=None, quality=None, attributes=None, local_vars_configuration=None):  # noqa: E501
        """ProcessParam - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._scenario = None
        self._only_central_face = None
        self._output_image_params = None
        self._quality = None
        self._attributes = None
        self.discriminator = None

        if scenario is not None:
            self.scenario = scenario
        if only_central_face is not None:
            self.only_central_face = only_central_face
        if output_image_params is not None:
            self.output_image_params = output_image_params
        if quality is not None:
            self.quality = quality
        if attributes is not None:
            self.attributes = attributes

    @property
    def scenario(self):
        """Gets the scenario of this ProcessParam.  # noqa: E501


        :return: The scenario of this ProcessParam.  # noqa: E501
        :rtype: FaceQualityScenarios
        """
        return self._scenario

    @scenario.setter
    def scenario(self, scenario):
        """Sets the scenario of this ProcessParam.


        :param scenario: The scenario of this ProcessParam.  # noqa: E501
        :type scenario: FaceQualityScenarios
        """

        self._scenario = scenario

    @property
    def only_central_face(self):
        """Gets the only_central_face of this ProcessParam.  # noqa: E501

        Whether to process only the central face in the image. If set to `false`, all the faces are processed.  # noqa: E501

        :return: The only_central_face of this ProcessParam.  # noqa: E501
        :rtype: bool
        """
        return self._only_central_face

    @only_central_face.setter
    def only_central_face(self, only_central_face):
        """Sets the only_central_face of this ProcessParam.

        Whether to process only the central face in the image. If set to `false`, all the faces are processed.  # noqa: E501

        :param only_central_face: The only_central_face of this ProcessParam.  # noqa: E501
        :type only_central_face: bool
        """

        self._only_central_face = only_central_face

    @property
    def output_image_params(self):
        """Gets the output_image_params of this ProcessParam.  # noqa: E501


        :return: The output_image_params of this ProcessParam.  # noqa: E501
        :rtype: OutputImageParams
        """
        return self._output_image_params

    @output_image_params.setter
    def output_image_params(self, output_image_params):
        """Sets the output_image_params of this ProcessParam.


        :param output_image_params: The output_image_params of this ProcessParam.  # noqa: E501
        :type output_image_params: OutputImageParams
        """

        self._output_image_params = output_image_params

    @property
    def quality(self):
        """Gets the quality of this ProcessParam.  # noqa: E501


        :return: The quality of this ProcessParam.  # noqa: E501
        :rtype: QualityRequest
        """
        return self._quality

    @quality.setter
    def quality(self, quality):
        """Sets the quality of this ProcessParam.


        :param quality: The quality of this ProcessParam.  # noqa: E501
        :type quality: QualityRequest
        """

        self._quality = quality

    @property
    def attributes(self):
        """Gets the attributes of this ProcessParam.  # noqa: E501


        :return: The attributes of this ProcessParam.  # noqa: E501
        :rtype: ProcessParamAttributes
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this ProcessParam.


        :param attributes: The attributes of this ProcessParam.  # noqa: E501
        :type attributes: ProcessParamAttributes
        """

        self._attributes = attributes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProcessParam):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProcessParam):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Regula Face SDK Web API

    <a href=\"https://regulaforensics.com/products/face-recognition-sdk/  \" target=\"_blank\">Regula Face SDK</a> is a cross-platform biometric verification solution for a digital identity verification process and image quality assurance. The SDK enables convenient and reliable face capture on the client side (mobile, web, and desktop) and further processing on the client or server side.   The Face SDK includes the following features:  * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-detection\" target=\"_blank\">Face detection and image quality assessment</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-comparison-11\" target=\"_blank\">Face match (1:1)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-identification-1n\" target=\"_blank\">Face search (1:N)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#liveness-assessment\" target=\"_blank\">Liveness detection</a>  Here is the <a href=\"https://github.com/regulaforensics/FaceSDK-web-openapi  \" target=\"_blank\">OpenAPI specification on GitHub</a>.   ### Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 7.2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from regula.facesdk.webclient.gen.configuration import Configuration


class DetectionQuality(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'non_compliant': '[FaceQualityConfigName]',
        'details_groups': '[QualityDetailsGroups]',
        'details': '[QualityDetail]',
        'score': 'float',
        'elapsed_time': 'float',
    }

    attribute_map = {
        'non_compliant': 'nonCompliant',
        'details_groups': 'detailsGroups',
        'details': 'details',
        'score': 'score',
        'elapsed_time': 'elapsedTime',
    }

    def __init__(self, non_compliant=None, details_groups=None, details=None, score=None, elapsed_time=None, local_vars_configuration=None):  # noqa: E501
        """DetectionQuality - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._non_compliant = None
        self._details_groups = None
        self._details = None
        self._score = None
        self._elapsed_time = None
        self.discriminator = None

        if non_compliant is not None:
            self.non_compliant = non_compliant
        if details_groups is not None:
            self.details_groups = details_groups
        if details is not None:
            self.details = details
        if score is not None:
            self.score = score
        if elapsed_time is not None:
            self.elapsed_time = elapsed_time

    @property
    def non_compliant(self):
        """Gets the non_compliant of this DetectionQuality.  # noqa: E501

        Non-compliant assessment characteristics.  # noqa: E501

        :return: The non_compliant of this DetectionQuality.  # noqa: E501
        :rtype: [FaceQualityConfigName]
        """
        return self._non_compliant

    @non_compliant.setter
    def non_compliant(self, non_compliant):
        """Sets the non_compliant of this DetectionQuality.

        Non-compliant assessment characteristics.  # noqa: E501

        :param non_compliant: The non_compliant of this DetectionQuality.  # noqa: E501
        :type non_compliant: [FaceQualityConfigName]
        """

        self._non_compliant = non_compliant

    @property
    def details_groups(self):
        """Gets the details_groups of this DetectionQuality.  # noqa: E501

        Assessment results for each [group of characteristics](https://docs.regulaforensics.com/develop/face-sdk/web-service/development/enums/face-image-quality-groups/).  # noqa: E501

        :return: The details_groups of this DetectionQuality.  # noqa: E501
        :rtype: [QualityDetailsGroups]
        """
        return self._details_groups

    @details_groups.setter
    def details_groups(self, details_groups):
        """Sets the details_groups of this DetectionQuality.

        Assessment results for each [group of characteristics](https://docs.regulaforensics.com/develop/face-sdk/web-service/development/enums/face-image-quality-groups/).  # noqa: E501

        :param details_groups: The details_groups of this DetectionQuality.  # noqa: E501
        :type details_groups: [QualityDetailsGroups]
        """

        self._details_groups = details_groups

    @property
    def details(self):
        """Gets the details of this DetectionQuality.  # noqa: E501

        Assessment characteristics that were set in the request.  # noqa: E501

        :return: The details of this DetectionQuality.  # noqa: E501
        :rtype: [QualityDetail]
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this DetectionQuality.

        Assessment characteristics that were set in the request.  # noqa: E501

        :param details: The details of this DetectionQuality.  # noqa: E501
        :type details: [QualityDetail]
        """

        self._details = details

    @property
    def score(self):
        """Gets the score of this DetectionQuality.  # noqa: E501

        Returns the estimated portrait quality assessment result, a number from `0` to `1`, where `1` is for absolute compliance.  # noqa: E501

        :return: The score of this DetectionQuality.  # noqa: E501
        :rtype: float
        """
        return self._score

    @score.setter
    def score(self, score):
        """Sets the score of this DetectionQuality.

        Returns the estimated portrait quality assessment result, a number from `0` to `1`, where `1` is for absolute compliance.  # noqa: E501

        :param score: The score of this DetectionQuality.  # noqa: E501
        :type score: float
        """

        self._score = score

    @property
    def elapsed_time(self):
        """Gets the elapsed_time of this DetectionQuality.  # noqa: E501

        Server processing time for quality assessment, ms.  # noqa: E501

        :return: The elapsed_time of this DetectionQuality.  # noqa: E501
        :rtype: float
        """
        return self._elapsed_time

    @elapsed_time.setter
    def elapsed_time(self, elapsed_time):
        """Sets the elapsed_time of this DetectionQuality.

        Server processing time for quality assessment, ms.  # noqa: E501

        :param elapsed_time: The elapsed_time of this DetectionQuality.  # noqa: E501
        :type elapsed_time: float
        """

        self._elapsed_time = elapsed_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DetectionQuality):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DetectionQuality):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Regula Face SDK Web API

    <a href=\"https://regulaforensics.com/products/face-recognition-sdk/  \" target=\"_blank\">Regula Face SDK</a> is a cross-platform biometric verification solution for a digital identity verification process and image quality assurance. The SDK enables convenient and reliable face capture on the client side (mobile, web, and desktop) and further processing on the client or server side.   The Face SDK includes the following features:  * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-detection\" target=\"_blank\">Face detection and image quality assessment</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-comparison-11\" target=\"_blank\">Face match (1:1)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-identification-1n\" target=\"_blank\">Face search (1:N)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#liveness-assessment\" target=\"_blank\">Liveness detection</a>  Here is the <a href=\"https://github.com/regulaforensics/FaceSDK-web-openapi  \" target=\"_blank\">OpenAPI specification on GitHub</a>.   ### Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 7.2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from regula.facesdk.webclient.gen.configuration import Configuration


class ImageFields(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'tag': 'str',
        'image': 'AddImageToPersonRequestImage',
        'output_image_params': 'OutputImageParams',
        'detect_all': 'bool',
        'threshold': 'float',
        'limit': 'int',
    }

    attribute_map = {
        'tag': 'tag',
        'image': 'image',
        'output_image_params': 'outputImageParams',
        'detect_all': 'detectAll',
        'threshold': 'threshold',
        'limit': 'limit',
    }

    def __init__(self, tag=None, image=None, output_image_params=None, detect_all=False, threshold=None, limit=None, local_vars_configuration=None):  # noqa: E501
        """ImageFields - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._tag = None
        self._image = None
        self._output_image_params = None
        self._detect_all = None
        self._threshold = None
        self._limit = None
        self.discriminator = None

        if tag is not None:
            self.tag = tag
        if image is not None:
            self.image = image
        if output_image_params is not None:
            self.output_image_params = output_image_params
        if detect_all is not None:
            self.detect_all = detect_all
        if threshold is not None:
            self.threshold = threshold
        if limit is not None:
            self.limit = limit

    @property
    def tag(self):
        """Gets the tag of this ImageFields.  # noqa: E501

        Session identificator, should be unique for each session.  # noqa: E501

        :return: The tag of this ImageFields.  # noqa: E501
        :rtype: str
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this ImageFields.

        Session identificator, should be unique for each session.  # noqa: E501

        :param tag: The tag of this ImageFields.  # noqa: E501
        :type tag: str
        """

        self._tag = tag

    @property
    def image(self):
        """Gets the image of this ImageFields.  # noqa: E501


        :return: The image of this ImageFields.  # noqa: E501
        :rtype: AddImageToPersonRequestImage
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this ImageFields.


        :param image: The image of this ImageFields.  # noqa: E501
        :type image: AddImageToPersonRequestImage
        """

        self._image = image

    @property
    def output_image_params(self):
        """Gets the output_image_params of this ImageFields.  # noqa: E501


        :return: The output_image_params of this ImageFields.  # noqa: E501
        :rtype: OutputImageParams
        """
        return self._output_image_params

    @output_image_params.setter
    def output_image_params(self, output_image_params):
        """Sets the output_image_params of this ImageFields.


        :param output_image_params: The output_image_params of this ImageFields.  # noqa: E501
        :type output_image_params: OutputImageParams
        """

        self._output_image_params = output_image_params

    @property
    def detect_all(self):
        """Gets the detect_all of this ImageFields.  # noqa: E501

        Whether to detect all faces in the image. If set to `false`, only the most central face is detected.  # noqa: E501

        :return: The detect_all of this ImageFields.  # noqa: E501
        :rtype: bool
        """
        return self._detect_all

    @detect_all.setter
    def detect_all(self, detect_all):
        """Sets the detect_all of this ImageFields.

        Whether to detect all faces in the image. If set to `false`, only the most central face is detected.  # noqa: E501

        :param detect_all: The detect_all of this ImageFields.  # noqa: E501
        :type detect_all: bool
        """

        self._detect_all = detect_all

    @property
    def threshold(self):
        """Gets the threshold of this ImageFields.  # noqa: E501

        The similarity threshold.  # noqa: E501

        :return: The threshold of this ImageFields.  # noqa: E501
        :rtype: float
        """
        return self._threshold

    @threshold.setter
    def threshold(self, threshold):
        """Sets the threshold of this ImageFields.

        The similarity threshold.  # noqa: E501

        :param threshold: The threshold of this ImageFields.  # noqa: E501
        :type threshold: float
        """

        self._threshold = threshold

    @property
    def limit(self):
        """Gets the limit of this ImageFields.  # noqa: E501

        The maximum number of results to be returned.  # noqa: E501

        :return: The limit of this ImageFields.  # noqa: E501
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this ImageFields.

        The maximum number of results to be returned.  # noqa: E501

        :param limit: The limit of this ImageFields.  # noqa: E501
        :type limit: int
        """

        self._limit = limit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImageFields):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ImageFields):
            return True

        return self.to_dict() != other.to_dict()



from typing import List, Union

from regula.facesdk.webclient.ext.common import Base64String
from regula.facesdk.webclient.ext.models.match_image import MatchImage
from regula.facesdk.webclient.gen import ApiValueError
from regula.facesdk.webclient.gen.models import MatchRequest as GenMatchRequest


class MatchRequest(GenMatchRequest):
    def __init__(
            self,
            images: List[Union[MatchImage, Base64String, bytes]],
            local_vars_configuration=None,
            output_image_params=None,
            tag=None
    ):
        if not images:
            raise ApiValueError(f"compare request images: expected size <more than 1>")

        input_images = []
        for index, item in enumerate(images):
            if isinstance(item, MatchImage):
                input_images.append(item)
            else:
                input_images.append(MatchImage(index, None, item, local_vars_configuration))

        super().__init__(
            images=input_images,
            local_vars_configuration=local_vars_configuration,
            output_image_params=output_image_params,
            tag=tag
        )



# coding: utf-8

"""
    Regula Face SDK Web API

    <a href=\"https://regulaforensics.com/products/face-recognition-sdk/  \" target=\"_blank\">Regula Face SDK</a> is a cross-platform biometric verification solution for a digital identity verification process and image quality assurance. The SDK enables convenient and reliable face capture on the client side (mobile, web, and desktop) and further processing on the client or server side.   The Face SDK includes the following features:  * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-detection\" target=\"_blank\">Face detection and image quality assessment</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-comparison-11\" target=\"_blank\">Face match (1:1)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-identification-1n\" target=\"_blank\">Face search (1:N)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#liveness-assessment\" target=\"_blank\">Liveness detection</a>  Here is the <a href=\"https://github.com/regulaforensics/FaceSDK-web-openapi  \" target=\"_blank\">OpenAPI specification on GitHub</a>.   ### Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 7.2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from regula.facesdk.webclient.gen.configuration import Configuration


class SearchDetection(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'code': 'int',
        'crop': 'str',
        'detector_type': 'int',
        'hash': 'str',
        'idx': 'int',
        'image': 'str',
        'landmarks': '[[int]]',
        'landmarks_type': 'int',
        'msg': 'str',
        'roi': 'FaceRectangular',
        'version_sdk': 'str',
    }

    attribute_map = {
        'code': 'code',
        'crop': 'crop',
        'detector_type': 'detectorType',
        'hash': 'hash',
        'idx': 'idx',
        'image': 'image',
        'landmarks': 'landmarks',
        'landmarks_type': 'landmarksType',
        'msg': 'msg',
        'roi': 'roi',
        'version_sdk': 'versionSDK',
    }

    def __init__(self, code=None, crop=None, detector_type=None, hash=None, idx=None, image=None, landmarks=None, landmarks_type=None, msg=None, roi=None, version_sdk=None, local_vars_configuration=None):  # noqa: E501
        """SearchDetection - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._code = None
        self._crop = None
        self._detector_type = None
        self._hash = None
        self._idx = None
        self._image = None
        self._landmarks = None
        self._landmarks_type = None
        self._msg = None
        self._roi = None
        self._version_sdk = None
        self.discriminator = None

        if code is not None:
            self.code = code
        if crop is not None:
            self.crop = crop
        if detector_type is not None:
            self.detector_type = detector_type
        if hash is not None:
            self.hash = hash
        if idx is not None:
            self.idx = idx
        if image is not None:
            self.image = image
        if landmarks is not None:
            self.landmarks = landmarks
        if landmarks_type is not None:
            self.landmarks_type = landmarks_type
        if msg is not None:
            self.msg = msg
        if roi is not None:
            self.roi = roi
        if version_sdk is not None:
            self.version_sdk = version_sdk

    @property
    def code(self):
        """Gets the code of this SearchDetection.  # noqa: E501

        Internal.  # noqa: E501

        :return: The code of this SearchDetection.  # noqa: E501
        :rtype: int
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this SearchDetection.

        Internal.  # noqa: E501

        :param code: The code of this SearchDetection.  # noqa: E501
        :type code: int
        """

        self._code = code

    @property
    def crop(self):
        """Gets the crop of this SearchDetection.  # noqa: E501

        Base64 of the aligned and cropped portrait.  # noqa: E501

        :return: The crop of this SearchDetection.  # noqa: E501
        :rtype: str
        """
        return self._crop

    @crop.setter
    def crop(self, crop):
        """Sets the crop of this SearchDetection.

        Base64 of the aligned and cropped portrait.  # noqa: E501

        :param crop: The crop of this SearchDetection.  # noqa: E501
        :type crop: str
        """

        self._crop = crop

    @property
    def detector_type(self):
        """Gets the detector_type of this SearchDetection.  # noqa: E501

        Internal.  # noqa: E501

        :return: The detector_type of this SearchDetection.  # noqa: E501
        :rtype: int
        """
        return self._detector_type

    @detector_type.setter
    def detector_type(self, detector_type):
        """Sets the detector_type of this SearchDetection.

        Internal.  # noqa: E501

        :param detector_type: The detector_type of this SearchDetection.  # noqa: E501
        :type detector_type: int
        """

        self._detector_type = detector_type

    @property
    def hash(self):
        """Gets the hash of this SearchDetection.  # noqa: E501

        Internal.  # noqa: E501

        :return: The hash of this SearchDetection.  # noqa: E501
        :rtype: str
        """
        return self._hash

    @hash.setter
    def hash(self, hash):
        """Sets the hash of this SearchDetection.

        Internal.  # noqa: E501

        :param hash: The hash of this SearchDetection.  # noqa: E501
        :type hash: str
        """

        self._hash = hash

    @property
    def idx(self):
        """Gets the idx of this SearchDetection.  # noqa: E501

        Internal.  # noqa: E501

        :return: The idx of this SearchDetection.  # noqa: E501
        :rtype: int
        """
        return self._idx

    @idx.setter
    def idx(self, idx):
        """Sets the idx of this SearchDetection.

        Internal.  # noqa: E501

        :param idx: The idx of this SearchDetection.  # noqa: E501
        :type idx: int
        """

        self._idx = idx

    @property
    def image(self):
        """Gets the image of this SearchDetection.  # noqa: E501

        Internal.  # noqa: E501

        :return: The image of this SearchDetection.  # noqa: E501
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this SearchDetection.

        Internal.  # noqa: E501

        :param image: The image of this SearchDetection.  # noqa: E501
        :type image: str
        """

        self._image = image

    @property
    def landmarks(self):
        """Gets the landmarks of this SearchDetection.  # noqa: E501

        Absolute coordinates (x,y) of five points of each detected face: left eye, right eye, nose, left point of lips, right point of lips.  # noqa: E501

        :return: The landmarks of this SearchDetection.  # noqa: E501
        :rtype: [[int]]
        """
        return self._landmarks

    @landmarks.setter
    def landmarks(self, landmarks):
        """Sets the landmarks of this SearchDetection.

        Absolute coordinates (x,y) of five points of each detected face: left eye, right eye, nose, left point of lips, right point of lips.  # noqa: E501

        :param landmarks: The landmarks of this SearchDetection.  # noqa: E501
        :type landmarks: [[int]]
        """

        self._landmarks = landmarks

    @property
    def landmarks_type(self):
        """Gets the landmarks_type of this SearchDetection.  # noqa: E501

        Internal.  # noqa: E501

        :return: The landmarks_type of this SearchDetection.  # noqa: E501
        :rtype: int
        """
        return self._landmarks_type

    @landmarks_type.setter
    def landmarks_type(self, landmarks_type):
        """Sets the landmarks_type of this SearchDetection.

        Internal.  # noqa: E501

        :param landmarks_type: The landmarks_type of this SearchDetection.  # noqa: E501
        :type landmarks_type: int
        """

        self._landmarks_type = landmarks_type

    @property
    def msg(self):
        """Gets the msg of this SearchDetection.  # noqa: E501

        Internal.  # noqa: E501

        :return: The msg of this SearchDetection.  # noqa: E501
        :rtype: str
        """
        return self._msg

    @msg.setter
    def msg(self, msg):
        """Sets the msg of this SearchDetection.

        Internal.  # noqa: E501

        :param msg: The msg of this SearchDetection.  # noqa: E501
        :type msg: str
        """

        self._msg = msg

    @property
    def roi(self):
        """Gets the roi of this SearchDetection.  # noqa: E501


        :return: The roi of this SearchDetection.  # noqa: E501
        :rtype: FaceRectangular
        """
        return self._roi

    @roi.setter
    def roi(self, roi):
        """Sets the roi of this SearchDetection.


        :param roi: The roi of this SearchDetection.  # noqa: E501
        :type roi: FaceRectangular
        """

        self._roi = roi

    @property
    def version_sdk(self):
        """Gets the version_sdk of this SearchDetection.  # noqa: E501


        :return: The version_sdk of this SearchDetection.  # noqa: E501
        :rtype: str
        """
        return self._version_sdk

    @version_sdk.setter
    def version_sdk(self, version_sdk):
        """Sets the version_sdk of this SearchDetection.


        :param version_sdk: The version_sdk of this SearchDetection.  # noqa: E501
        :type version_sdk: str
        """

        self._version_sdk = version_sdk

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchDetection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SearchDetection):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Regula Face SDK Web API

    <a href=\"https://regulaforensics.com/products/face-recognition-sdk/  \" target=\"_blank\">Regula Face SDK</a> is a cross-platform biometric verification solution for a digital identity verification process and image quality assurance. The SDK enables convenient and reliable face capture on the client side (mobile, web, and desktop) and further processing on the client or server side.   The Face SDK includes the following features:  * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-detection\" target=\"_blank\">Face detection and image quality assessment</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-comparison-11\" target=\"_blank\">Face match (1:1)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-identification-1n\" target=\"_blank\">Face search (1:N)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#liveness-assessment\" target=\"_blank\">Liveness detection</a>  Here is the <a href=\"https://github.com/regulaforensics/FaceSDK-web-openapi  \" target=\"_blank\">OpenAPI specification on GitHub</a>.   ### Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 6.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from regula.facesdk.webclient.gen.configuration import Configuration


class MatchRequestOutputImageParamsCrop(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pad_color': '[int]',
        'return_original_rect': 'bool',
        'size': '[int]',
        'type': 'int',
    }

    attribute_map = {
        'pad_color': 'padColor',
        'return_original_rect': 'returnOriginalRect',
        'size': 'size',
        'type': 'type',
    }

    def __init__(self, pad_color=None, return_original_rect=None, size=None, type=None, local_vars_configuration=None):  # noqa: E501
        """MatchRequestOutputImageParamsCrop - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pad_color = None
        self._return_original_rect = None
        self._size = None
        self._type = None
        self.discriminator = None

        if pad_color is not None:
            self.pad_color = pad_color
        if return_original_rect is not None:
            self.return_original_rect = return_original_rect
        if size is not None:
            self.size = size
        if type is not None:
            self.type = type

    @property
    def pad_color(self):
        """Gets the pad_color of this MatchRequestOutputImageParamsCrop.  # noqa: E501

        The RGB value of a color for filling background behind a person's silhouette and for aligning the image.  # noqa: E501

        :return: The pad_color of this MatchRequestOutputImageParamsCrop.  # noqa: E501
        :rtype: [int]
        """
        return self._pad_color

    @pad_color.setter
    def pad_color(self, pad_color):
        """Sets the pad_color of this MatchRequestOutputImageParamsCrop.

        The RGB value of a color for filling background behind a person's silhouette and for aligning the image.  # noqa: E501

        :param pad_color: The pad_color of this MatchRequestOutputImageParamsCrop.  # noqa: E501
        :type pad_color: [int]
        """

        self._pad_color = pad_color

    @property
    def return_original_rect(self):
        """Gets the return_original_rect of this MatchRequestOutputImageParamsCrop.  # noqa: E501

        Whether to return the coordinates of the rectangle with the face in the original image prepared for the face crop.  # noqa: E501

        :return: The return_original_rect of this MatchRequestOutputImageParamsCrop.  # noqa: E501
        :rtype: bool
        """
        return self._return_original_rect

    @return_original_rect.setter
    def return_original_rect(self, return_original_rect):
        """Sets the return_original_rect of this MatchRequestOutputImageParamsCrop.

        Whether to return the coordinates of the rectangle with the face in the original image prepared for the face crop.  # noqa: E501

        :param return_original_rect: The return_original_rect of this MatchRequestOutputImageParamsCrop.  # noqa: E501
        :type return_original_rect: bool
        """

        self._return_original_rect = return_original_rect

    @property
    def size(self):
        """Gets the size of this MatchRequestOutputImageParamsCrop.  # noqa: E501

        The resize value in case `type` matches this value. If it doesn't, no resize is performed.  # noqa: E501

        :return: The size of this MatchRequestOutputImageParamsCrop.  # noqa: E501
        :rtype: [int]
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this MatchRequestOutputImageParamsCrop.

        The resize value in case `type` matches this value. If it doesn't, no resize is performed.  # noqa: E501

        :param size: The size of this MatchRequestOutputImageParamsCrop.  # noqa: E501
        :type size: [int]
        """

        self._size = size

    @property
    def type(self):
        """Gets the type of this MatchRequestOutputImageParamsCrop.  # noqa: E501

        The aspect ratio according to which face alignment is performed. See the [FaceImageQualityAlignType enum](https://docs.regulaforensics.com/develop/face-sdk/web-service/development/enums/face-image-quality-align-type/). To get a thumbnail with aspect ratio 3:4, set `0`.  # noqa: E501

        :return: The type of this MatchRequestOutputImageParamsCrop.  # noqa: E501
        :rtype: int
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this MatchRequestOutputImageParamsCrop.

        The aspect ratio according to which face alignment is performed. See the [FaceImageQualityAlignType enum](https://docs.regulaforensics.com/develop/face-sdk/web-service/development/enums/face-image-quality-align-type/). To get a thumbnail with aspect ratio 3:4, set `0`.  # noqa: E501

        :param type: The type of this MatchRequestOutputImageParamsCrop.  # noqa: E501
        :type type: int
        """
        allowed_values = [0, 1, 2, 3, 4]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MatchRequestOutputImageParamsCrop):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MatchRequestOutputImageParamsCrop):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Regula Face SDK Web API

    <a href=\"https://regulaforensics.com/products/face-recognition-sdk/  \" target=\"_blank\">Regula Face SDK</a> is a cross-platform biometric verification solution for a digital identity verification process and image quality assurance. The SDK enables convenient and reliable face capture on the client side (mobile, web, and desktop) and further processing on the client or server side.   The Face SDK includes the following features:  * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-detection\" target=\"_blank\">Face detection and image quality assessment</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-comparison-11\" target=\"_blank\">Face match (1:1)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-identification-1n\" target=\"_blank\">Face search (1:N)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#liveness-assessment\" target=\"_blank\">Liveness detection</a>  Here is the <a href=\"https://github.com/regulaforensics/FaceSDK-web-openapi  \" target=\"_blank\">OpenAPI specification on GitHub</a>.   ### Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 7.2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from regula.facesdk.webclient.gen.configuration import Configuration


class DetectionFace(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'face_index': 'float',
        'landmarks': '[[float]]',
        'rotation_angle': 'float',
        'roi': 'FaceRectangular',
        'crop': 'str',
    }

    attribute_map = {
        'face_index': 'faceIndex',
        'landmarks': 'landmarks',
        'rotation_angle': 'rotationAngle',
        'roi': 'roi',
        'crop': 'crop',
    }

    def __init__(self, face_index=None, landmarks=None, rotation_angle=None, roi=None, crop=None, local_vars_configuration=None):  # noqa: E501
        """DetectionFace - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._face_index = None
        self._landmarks = None
        self._rotation_angle = None
        self._roi = None
        self._crop = None
        self.discriminator = None

        if face_index is not None:
            self.face_index = face_index
        if landmarks is not None:
            self.landmarks = landmarks
        if rotation_angle is not None:
            self.rotation_angle = rotation_angle
        if roi is not None:
            self.roi = roi
        if crop is not None:
            self.crop = crop

    @property
    def face_index(self):
        """Gets the face_index of this DetectionFace.  # noqa: E501

        The detected face index number.  # noqa: E501

        :return: The face_index of this DetectionFace.  # noqa: E501
        :rtype: float
        """
        return self._face_index

    @face_index.setter
    def face_index(self, face_index):
        """Sets the face_index of this DetectionFace.

        The detected face index number.  # noqa: E501

        :param face_index: The face_index of this DetectionFace.  # noqa: E501
        :type face_index: float
        """

        self._face_index = face_index

    @property
    def landmarks(self):
        """Gets the landmarks of this DetectionFace.  # noqa: E501

        Absolute coordinates (x,y) of five points of each detected face: left eye, right eye, nose, left point of lips, right point of lips.  # noqa: E501

        :return: The landmarks of this DetectionFace.  # noqa: E501
        :rtype: [[float]]
        """
        return self._landmarks

    @landmarks.setter
    def landmarks(self, landmarks):
        """Sets the landmarks of this DetectionFace.

        Absolute coordinates (x,y) of five points of each detected face: left eye, right eye, nose, left point of lips, right point of lips.  # noqa: E501

        :param landmarks: The landmarks of this DetectionFace.  # noqa: E501
        :type landmarks: [[float]]
        """

        self._landmarks = landmarks

    @property
    def rotation_angle(self):
        """Gets the rotation_angle of this DetectionFace.  # noqa: E501

        Angle of rotation of the face from the vertical axis, degrees.  # noqa: E501

        :return: The rotation_angle of this DetectionFace.  # noqa: E501
        :rtype: float
        """
        return self._rotation_angle

    @rotation_angle.setter
    def rotation_angle(self, rotation_angle):
        """Sets the rotation_angle of this DetectionFace.

        Angle of rotation of the face from the vertical axis, degrees.  # noqa: E501

        :param rotation_angle: The rotation_angle of this DetectionFace.  # noqa: E501
        :type rotation_angle: float
        """

        self._rotation_angle = rotation_angle

    @property
    def roi(self):
        """Gets the roi of this DetectionFace.  # noqa: E501


        :return: The roi of this DetectionFace.  # noqa: E501
        :rtype: FaceRectangular
        """
        return self._roi

    @roi.setter
    def roi(self, roi):
        """Sets the roi of this DetectionFace.


        :param roi: The roi of this DetectionFace.  # noqa: E501
        :type roi: FaceRectangular
        """

        self._roi = roi

    @property
    def crop(self):
        """Gets the crop of this DetectionFace.  # noqa: E501

        Base64-encoded aligned and cropped portrait.  # noqa: E501

        :return: The crop of this DetectionFace.  # noqa: E501
        :rtype: str
        """
        return self._crop

    @crop.setter
    def crop(self, crop):
        """Sets the crop of this DetectionFace.

        Base64-encoded aligned and cropped portrait.  # noqa: E501

        :param crop: The crop of this DetectionFace.  # noqa: E501
        :type crop: str
        """

        self._crop = crop

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DetectionFace):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DetectionFace):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8
import os

from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="regula_facesdk_webclient",
    version=os.getenv("PACKAGE_VERSION_TO_PUBLISH", "6.2dev"),
    python_requires=">=3.9",
    description="Regula's FaceSDK web python client",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Regula Forensics, Inc.",
    author_email="support@regulaforensics.com",
    url="https://regulaforensics.com",
    keywords=["face recognition", "facesdk", "regulaforensics", "regula"],
    install_requires=[
        "certifi>=2024.07.04",
        "six>=1.10",
        "python-dateutil>=2.5.3",
        "urllib3>=2.2.2",
        "vistir>=0.4.0, <=0.6.1",
        "idna==3.7",
        "requests>=2.32.3",
    ],
    packages=find_packages(exclude=["test", "tests", "example"]),
    include_package_data=True,
)



# coding: utf-8

"""
    Regula FaceSDK Web API

    Regula FaceSDK Web API # Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 4.1.3
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from regula.facesdk.webclient.gen.configuration import Configuration


class LivenessTransaction(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'code': 'int',
        'config': 'TransactionConfig',
        'elapsed': 'int',
        'portrait': 'str',
        'session_id': 'str',
        'status': 'int',
        'transaction_id': 'str',
        'video': 'str',
        'metadata': '{str: (bool, date, datetime, dict, float, int, list, str, none_type)}',
    }

    attribute_map = {
        'code': 'code',
        'config': 'config',
        'elapsed': 'elapsed',
        'portrait': 'portrait',
        'session_id': 'sessionId',
        'status': 'status',
        'transaction_id': 'transactionId',
        'video': 'video',
        'metadata': 'metadata',
    }

    def __init__(self, code=None, config=None, elapsed=None, portrait=None, session_id=None, status=None, transaction_id=None, video=None, metadata=None, local_vars_configuration=None):  # noqa: E501
        """LivenessTransaction - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._code = None
        self._config = None
        self._elapsed = None
        self._portrait = None
        self._session_id = None
        self._status = None
        self._transaction_id = None
        self._video = None
        self._metadata = None
        self.discriminator = None

        if code is not None:
            self.code = code
        if config is not None:
            self.config = config
        if elapsed is not None:
            self.elapsed = elapsed
        if portrait is not None:
            self.portrait = portrait
        if session_id is not None:
            self.session_id = session_id
        if status is not None:
            self.status = status
        if transaction_id is not None:
            self.transaction_id = transaction_id
        if video is not None:
            self.video = video
        if metadata is not None:
            self.metadata = metadata

    @property
    def code(self):
        """Gets the code of this LivenessTransaction.  # noqa: E501


        :return: The code of this LivenessTransaction.  # noqa: E501
        :rtype: int
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this LivenessTransaction.


        :param code: The code of this LivenessTransaction.  # noqa: E501
        :type code: int
        """

        self._code = code

    @property
    def config(self):
        """Gets the config of this LivenessTransaction.  # noqa: E501


        :return: The config of this LivenessTransaction.  # noqa: E501
        :rtype: TransactionConfig
        """
        return self._config

    @config.setter
    def config(self, config):
        """Sets the config of this LivenessTransaction.


        :param config: The config of this LivenessTransaction.  # noqa: E501
        :type config: TransactionConfig
        """

        self._config = config

    @property
    def elapsed(self):
        """Gets the elapsed of this LivenessTransaction.  # noqa: E501


        :return: The elapsed of this LivenessTransaction.  # noqa: E501
        :rtype: int
        """
        return self._elapsed

    @elapsed.setter
    def elapsed(self, elapsed):
        """Sets the elapsed of this LivenessTransaction.


        :param elapsed: The elapsed of this LivenessTransaction.  # noqa: E501
        :type elapsed: int
        """

        self._elapsed = elapsed

    @property
    def portrait(self):
        """Gets the portrait of this LivenessTransaction.  # noqa: E501

        URL for portrait image  # noqa: E501

        :return: The portrait of this LivenessTransaction.  # noqa: E501
        :rtype: str
        """
        return self._portrait

    @portrait.setter
    def portrait(self, portrait):
        """Sets the portrait of this LivenessTransaction.

        URL for portrait image  # noqa: E501

        :param portrait: The portrait of this LivenessTransaction.  # noqa: E501
        :type portrait: str
        """

        self._portrait = portrait

    @property
    def session_id(self):
        """Gets the session_id of this LivenessTransaction.  # noqa: E501


        :return: The session_id of this LivenessTransaction.  # noqa: E501
        :rtype: str
        """
        return self._session_id

    @session_id.setter
    def session_id(self, session_id):
        """Sets the session_id of this LivenessTransaction.


        :param session_id: The session_id of this LivenessTransaction.  # noqa: E501
        :type session_id: str
        """

        self._session_id = session_id

    @property
    def status(self):
        """Gets the status of this LivenessTransaction.  # noqa: E501

        Whether the liveness detection is confirmed (0) or not (1)  # noqa: E501

        :return: The status of this LivenessTransaction.  # noqa: E501
        :rtype: int
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this LivenessTransaction.

        Whether the liveness detection is confirmed (0) or not (1)  # noqa: E501

        :param status: The status of this LivenessTransaction.  # noqa: E501
        :type status: int
        """

        self._status = status

    @property
    def transaction_id(self):
        """Gets the transaction_id of this LivenessTransaction.  # noqa: E501


        :return: The transaction_id of this LivenessTransaction.  # noqa: E501
        :rtype: str
        """
        return self._transaction_id

    @transaction_id.setter
    def transaction_id(self, transaction_id):
        """Sets the transaction_id of this LivenessTransaction.


        :param transaction_id: The transaction_id of this LivenessTransaction.  # noqa: E501
        :type transaction_id: str
        """

        self._transaction_id = transaction_id

    @property
    def video(self):
        """Gets the video of this LivenessTransaction.  # noqa: E501


        :return: The video of this LivenessTransaction.  # noqa: E501
        :rtype: str
        """
        return self._video

    @video.setter
    def video(self, video):
        """Sets the video of this LivenessTransaction.


        :param video: The video of this LivenessTransaction.  # noqa: E501
        :type video: str
        """

        self._video = video

    @property
    def metadata(self):
        """Gets the metadata of this LivenessTransaction.  # noqa: E501

        A free-form object containing the request information (server time, client IP, etc.).  # noqa: E501

        :return: The metadata of this LivenessTransaction.  # noqa: E501
        :rtype: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this LivenessTransaction.

        A free-form object containing the request information (server time, client IP, etc.).  # noqa: E501

        :param metadata: The metadata of this LivenessTransaction.  # noqa: E501
        :type metadata: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """

        self._metadata = metadata

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LivenessTransaction):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LivenessTransaction):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Regula Face SDK Web API

    <a href=\"https://regulaforensics.com/products/face-recognition-sdk/  \" target=\"_blank\">Regula Face SDK</a> is a cross-platform biometric verification solution for a digital identity verification process and image quality assurance. The SDK enables convenient and reliable face capture on the client side (mobile, web, and desktop) and further processing on the client or server side.   The Face SDK includes the following features:  * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-detection\" target=\"_blank\">Face detection and image quality assessment</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-comparison-11\" target=\"_blank\">Face match (1:1)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-identification-1n\" target=\"_blank\">Face search (1:N)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#liveness-assessment\" target=\"_blank\">Liveness detection</a>  Here is the <a href=\"https://github.com/regulaforensics/FaceSDK-web-openapi  \" target=\"_blank\">OpenAPI specification on GitHub</a>.   ### Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 7.2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from regula.facesdk.webclient.gen.configuration import Configuration


class MatchImage(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'index': 'int',
        'type': 'ImageSource',
        'data': 'str',
        'detect_all': 'bool',
    }

    attribute_map = {
        'index': 'index',
        'type': 'type',
        'data': 'data',
        'detect_all': 'detectAll',
    }

    def __init__(self, index=None, type=None, data=None, detect_all=False, local_vars_configuration=None):  # noqa: E501
        """MatchImage - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._index = None
        self._type = None
        self._data = None
        self._detect_all = None
        self.discriminator = None

        if index is not None:
            self.index = index
        if type is not None:
            self.type = type
        self.data = data
        if detect_all is not None:
            self.detect_all = detect_all

    @property
    def index(self):
        """Gets the index of this MatchImage.  # noqa: E501

        The image index number. Can be given; if not given, the index numbers are set automatically starting from `0`. All index numbers must be whole and unique—not repeated.  # noqa: E501

        :return: The index of this MatchImage.  # noqa: E501
        :rtype: int
        """
        return self._index

    @index.setter
    def index(self, index):
        """Sets the index of this MatchImage.

        The image index number. Can be given; if not given, the index numbers are set automatically starting from `0`. All index numbers must be whole and unique—not repeated.  # noqa: E501

        :param index: The index of this MatchImage.  # noqa: E501
        :type index: int
        """

        self._index = index

    @property
    def type(self):
        """Gets the type of this MatchImage.  # noqa: E501


        :return: The type of this MatchImage.  # noqa: E501
        :rtype: ImageSource
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this MatchImage.


        :param type: The type of this MatchImage.  # noqa: E501
        :type type: ImageSource
        """

        self._type = type

    @property
    def data(self):
        """Gets the data of this MatchImage.  # noqa: E501

        Base64-encoded image.  # noqa: E501

        :return: The data of this MatchImage.  # noqa: E501
        :rtype: str
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this MatchImage.

        Base64-encoded image.  # noqa: E501

        :param data: The data of this MatchImage.  # noqa: E501
        :type data: str
        """
        if self.local_vars_configuration.client_side_validation and data is None:  # noqa: E501
            raise ValueError("Invalid value for `data`, must not be `None`")  # noqa: E501

        self._data = data

    @property
    def detect_all(self):
        """Gets the detect_all of this MatchImage.  # noqa: E501

        Whether to detect all faces in the image. If set to `false`, only the most central face is detected.  # noqa: E501

        :return: The detect_all of this MatchImage.  # noqa: E501
        :rtype: bool
        """
        return self._detect_all

    @detect_all.setter
    def detect_all(self, detect_all):
        """Sets the detect_all of this MatchImage.

        Whether to detect all faces in the image. If set to `false`, only the most central face is detected.  # noqa: E501

        :param detect_all: The detect_all of this MatchImage.  # noqa: E501
        :type detect_all: bool
        """

        self._detect_all = detect_all

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MatchImage):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MatchImage):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Regula Face SDK Web API

    <a href=\"https://regulaforensics.com/products/face-recognition-sdk/  \" target=\"_blank\">Regula Face SDK</a> is a cross-platform biometric verification solution for a digital identity verification process and image quality assurance. The SDK enables convenient and reliable face capture on the client side (mobile, web, and desktop) and further processing on the client or server side.   The Face SDK includes the following features:  * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-detection\" target=\"_blank\">Face detection and image quality assessment</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-comparison-11\" target=\"_blank\">Face match (1:1)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-identification-1n\" target=\"_blank\">Face search (1:N)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#liveness-assessment\" target=\"_blank\">Liveness detection</a>  Here is the <a href=\"https://github.com/regulaforensics/FaceSDK-web-openapi  \" target=\"_blank\">OpenAPI specification on GitHub</a>.   ### Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 6.2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from regula.facesdk.webclient.gen.api_client import ApiClient
from regula.facesdk.webclient.gen.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class DiagnosticsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def readiness(self, **kwargs):  # noqa: E501
        """Checking the license status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.readiness(async_req=True)
        >>> result = thread.get()

        :param x_request_id: Request header label.
        :type x_request_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """
        kwargs['_return_http_data_only'] = True
        return self.readiness_with_http_info(**kwargs)  # noqa: E501

    def readiness_with_http_info(self, **kwargs):  # noqa: E501
        """Checking the license status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.readiness_with_http_info(async_req=True)
        >>> result = thread.get()

        :param x_request_id: Request header label.
        :type x_request_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'x_request_id',
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method readiness" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_request_id' in local_var_params:
            header_params['X-RequestID'] = local_var_params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/readiness', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='{str: (bool, date, datetime, dict, float, int, list, str, none_type)}',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))



# coding: utf-8

"""
    Regula Face SDK Web API

    <a href=\"https://regulaforensics.com/products/face-recognition-sdk/  \" target=\"_blank\">Regula Face SDK</a> is a cross-platform biometric verification solution for a digital identity verification process and image quality assurance. The SDK enables convenient and reliable face capture on the client side (mobile, web, and desktop) and further processing on the client or server side.   The Face SDK includes the following features:  * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-detection\" target=\"_blank\">Face detection and image quality assessment</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-comparison-11\" target=\"_blank\">Face match (1:1)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-identification-1n\" target=\"_blank\">Face search (1:N)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#liveness-assessment\" target=\"_blank\">Liveness detection</a>  Here is the <a href=\"https://github.com/regulaforensics/FaceSDK-web-openapi  \" target=\"_blank\">OpenAPI specification on GitHub</a>.   ### Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 7.2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from regula.facesdk.webclient.gen.configuration import Configuration


class RecognizeImage(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'content': 'str',
        'content_type': 'str',
        'created_at': 'str',
        'updated_at': 'str',
        'path': 'str',
        'url': 'str',
        'metadata': '{str: (bool, date, datetime, dict, float, int, list, str, none_type)}',
        'similarity': 'float',
        'distance': 'float',
    }

    attribute_map = {
        'id': 'id',
        'content': 'content',
        'content_type': 'contentType',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt',
        'path': 'path',
        'url': 'url',
        'metadata': 'metadata',
        'similarity': 'similarity',
        'distance': 'distance',
    }

    def __init__(self, id=None, content=None, content_type=None, created_at=None, updated_at=None, path=None, url=None, metadata=None, similarity=None, distance=None, local_vars_configuration=None):  # noqa: E501
        """RecognizeImage - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._content = None
        self._content_type = None
        self._created_at = None
        self._updated_at = None
        self._path = None
        self._url = None
        self._metadata = None
        self._similarity = None
        self._distance = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if content is not None:
            self.content = content
        if content_type is not None:
            self.content_type = content_type
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if path is not None:
            self.path = path
        if url is not None:
            self.url = url
        if metadata is not None:
            self.metadata = metadata
        if similarity is not None:
            self.similarity = similarity
        if distance is not None:
            self.distance = distance

    @property
    def id(self):
        """Gets the id of this RecognizeImage.  # noqa: E501

        Response image ID. The list is sorted by decreasing ID value.  # noqa: E501

        :return: The id of this RecognizeImage.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RecognizeImage.

        Response image ID. The list is sorted by decreasing ID value.  # noqa: E501

        :param id: The id of this RecognizeImage.  # noqa: E501
        :type id: str
        """

        self._id = id

    @property
    def content(self):
        """Gets the content of this RecognizeImage.  # noqa: E501

        Base64-encoded image. Returned only if `withImages` is set to true in the request.  # noqa: E501

        :return: The content of this RecognizeImage.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this RecognizeImage.

        Base64-encoded image. Returned only if `withImages` is set to true in the request.  # noqa: E501

        :param content: The content of this RecognizeImage.  # noqa: E501
        :type content: str
        """

        self._content = content

    @property
    def content_type(self):
        """Gets the content_type of this RecognizeImage.  # noqa: E501

        Original media type of the returned image.  # noqa: E501

        :return: The content_type of this RecognizeImage.  # noqa: E501
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """Sets the content_type of this RecognizeImage.

        Original media type of the returned image.  # noqa: E501

        :param content_type: The content_type of this RecognizeImage.  # noqa: E501
        :type content_type: str
        """

        self._content_type = content_type

    @property
    def created_at(self):
        """Gets the created_at of this RecognizeImage.  # noqa: E501

        Returned image creation date.  # noqa: E501

        :return: The created_at of this RecognizeImage.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this RecognizeImage.

        Returned image creation date.  # noqa: E501

        :param created_at: The created_at of this RecognizeImage.  # noqa: E501
        :type created_at: str
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this RecognizeImage.  # noqa: E501

        Returned image update date.  # noqa: E501

        :return: The updated_at of this RecognizeImage.  # noqa: E501
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this RecognizeImage.

        Returned image update date.  # noqa: E501

        :param updated_at: The updated_at of this RecognizeImage.  # noqa: E501
        :type updated_at: str
        """

        self._updated_at = updated_at

    @property
    def path(self):
        """Gets the path of this RecognizeImage.  # noqa: E501

        Returned image path.  # noqa: E501

        :return: The path of this RecognizeImage.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this RecognizeImage.

        Returned image path.  # noqa: E501

        :param path: The path of this RecognizeImage.  # noqa: E501
        :type path: str
        """

        self._path = path

    @property
    def url(self):
        """Gets the url of this RecognizeImage.  # noqa: E501

        Returned image URL.  # noqa: E501

        :return: The url of this RecognizeImage.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this RecognizeImage.

        Returned image URL.  # noqa: E501

        :param url: The url of this RecognizeImage.  # noqa: E501
        :type url: str
        """

        self._url = url

    @property
    def metadata(self):
        """Gets the metadata of this RecognizeImage.  # noqa: E501

        A free-form object containing person's extended attributes.  # noqa: E501

        :return: The metadata of this RecognizeImage.  # noqa: E501
        :rtype: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this RecognizeImage.

        A free-form object containing person's extended attributes.  # noqa: E501

        :param metadata: The metadata of this RecognizeImage.  # noqa: E501
        :type metadata: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """

        self._metadata = metadata

    @property
    def similarity(self):
        """Gets the similarity of this RecognizeImage.  # noqa: E501

        Similarity score.  # noqa: E501

        :return: The similarity of this RecognizeImage.  # noqa: E501
        :rtype: float
        """
        return self._similarity

    @similarity.setter
    def similarity(self, similarity):
        """Sets the similarity of this RecognizeImage.

        Similarity score.  # noqa: E501

        :param similarity: The similarity of this RecognizeImage.  # noqa: E501
        :type similarity: float
        """

        self._similarity = similarity

    @property
    def distance(self):
        """Gets the distance of this RecognizeImage.  # noqa: E501

        Similarity distance score: the lower the distance, the higher the face's similarity.  # noqa: E501

        :return: The distance of this RecognizeImage.  # noqa: E501
        :rtype: float
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this RecognizeImage.

        Similarity distance score: the lower the distance, the higher the face's similarity.  # noqa: E501

        :param distance: The distance of this RecognizeImage.  # noqa: E501
        :type distance: float
        """

        self._distance = distance

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RecognizeImage):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RecognizeImage):
            return True

        return self.to_dict() != other.to_dict()



# flake8: noqa

"""
    Regula Face SDK Web API

    <a href=\"https://regulaforensics.com/products/face-recognition-sdk/  \" target=\"_blank\">Regula Face SDK</a> is a cross-platform biometric verification solution for a digital identity verification process and image quality assurance. The SDK enables convenient and reliable face capture on the client side (mobile, web, and desktop) and further processing on the client or server side.   The Face SDK includes the following features:  * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-detection\" target=\"_blank\">Face detection and image quality assessment</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-comparison-11\" target=\"_blank\">Face match (1:1)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-identification-1n\" target=\"_blank\">Face search (1:N)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#liveness-assessment\" target=\"_blank\">Liveness detection</a>  Here is the <a href=\"https://github.com/regulaforensics/FaceSDK-web-openapi  \" target=\"_blank\">OpenAPI specification on GitHub</a>.   ### Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 7.2.0
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.0.0"

# import ApiClient
from regula.facesdk.webclient.gen.api_client import ApiClient

# import Configuration
from regula.facesdk.webclient.gen.configuration import Configuration

# import exceptions
from regula.facesdk.webclient.gen.exceptions import OpenApiException
from regula.facesdk.webclient.gen.exceptions import ApiAttributeError
from regula.facesdk.webclient.gen.exceptions import ApiTypeError
from regula.facesdk.webclient.gen.exceptions import ApiValueError
from regula.facesdk.webclient.gen.exceptions import ApiKeyError
from regula.facesdk.webclient.gen.exceptions import ApiException



from typing import List

from regula.facesdk.webclient.gen import Configuration, ApiClient
from regula.facesdk.webclient.gen.apis import MatchApi as GenMatchApi
from regula.facesdk.webclient.ext.models import MatchRequest, DetectRequest
from regula.facesdk.webclient.gen.model.detect_response import DetectResponse
from regula.facesdk.webclient.gen.model.match_and_search_request import MatchAndSearchRequest
from regula.facesdk.webclient.gen.model.match_and_search_request_all_of_images import MatchAndSearchRequestAllOfImages
from regula.facesdk.webclient.gen.model.match_and_search_response import MatchAndSearchResponse
from regula.facesdk.webclient.gen.model.match_response import MatchResponse


class MatchApi(GenMatchApi):
    def __init__(self, host=None, debug=False, verify_ssl=False, api_client=None):
        if api_client:
            super().__init__(api_client)
        else:
            configuration = Configuration(host=host)
            configuration.debug = debug
            configuration.verify_ssl = verify_ssl

            super().__init__(ApiClient(configuration=configuration))

    def __enter__(self):
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        self.api_client.close()

    def match_and_search(self, images: List[MatchAndSearchRequestAllOfImages], group_ids: List[int],
                         limit: int = 100, threshold: float = 1.0) -> MatchAndSearchResponse:
        body = MatchAndSearchRequest(
            images=images,
            group_ids=group_ids
        )
        return super().match_and_search(body)

    def match(self, match_request: MatchRequest, **kwargs) -> MatchResponse:
        return super().match(match_request, **kwargs)

    # deprecated use match
    def compare(self, compare_request: MatchRequest, **kwargs) -> MatchResponse:
        return super().match(compare_request, **kwargs)

    def detect(self, detect_request: DetectRequest, **kwargs) -> DetectResponse:
        return super().detect(detect_request, **kwargs)



# coding: utf-8

"""
    Regula Face SDK Web API

    <a href=\"https://regulaforensics.com/products/face-recognition-sdk/  \" target=\"_blank\">Regula Face SDK</a> is a cross-platform biometric verification solution for a digital identity verification process and image quality assurance. The SDK enables convenient and reliable face capture on the client side (mobile, web, and desktop) and further processing on the client or server side.   The Face SDK includes the following features:  * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-detection\" target=\"_blank\">Face detection and image quality assessment</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-comparison-11\" target=\"_blank\">Face match (1:1)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-identification-1n\" target=\"_blank\">Face search (1:N)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#liveness-assessment\" target=\"_blank\">Liveness detection</a>  Here is the <a href=\"https://github.com/regulaforensics/FaceSDK-web-openapi  \" target=\"_blank\">OpenAPI specification on GitHub</a>.   ### Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 7.2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from regula.facesdk.webclient.gen.configuration import Configuration


class TransactionInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'code': 'int',
        'status': 'int',
        'tag': 'str',
        'transaction_id': 'str',
        'video': 'str',
        'age': '[{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]',
        'portrait': 'str',
        'metadata': '{str: (bool, date, datetime, dict, float, int, list, str, none_type)}',
        'type': 'LivenessType',
    }

    attribute_map = {
        'code': 'code',
        'status': 'status',
        'tag': 'tag',
        'transaction_id': 'transactionId',
        'video': 'video',
        'age': 'age',
        'portrait': 'portrait',
        'metadata': 'metadata',
        'type': 'type',
    }

    def __init__(self, code=None, status=None, tag=None, transaction_id=None, video=None, age=None, portrait=None, metadata=None, type=None, local_vars_configuration=None):  # noqa: E501
        """TransactionInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._code = None
        self._status = None
        self._tag = None
        self._transaction_id = None
        self._video = None
        self._age = None
        self._portrait = None
        self._metadata = None
        self._type = None
        self.discriminator = None

        if code is not None:
            self.code = code
        if status is not None:
            self.status = status
        if tag is not None:
            self.tag = tag
        if transaction_id is not None:
            self.transaction_id = transaction_id
        if video is not None:
            self.video = video
        if age is not None:
            self.age = age
        if portrait is not None:
            self.portrait = portrait
        if metadata is not None:
            self.metadata = metadata
        if type is not None:
            self.type = type

    @property
    def code(self):
        """Gets the code of this TransactionInfo.  # noqa: E501

        Result code, see the [FaceSDKResultCode enum](https://docs.regulaforensics.com/develop/face-sdk/web-service/development/enums/face-sdk-result-code/).  # noqa: E501

        :return: The code of this TransactionInfo.  # noqa: E501
        :rtype: int
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this TransactionInfo.

        Result code, see the [FaceSDKResultCode enum](https://docs.regulaforensics.com/develop/face-sdk/web-service/development/enums/face-sdk-result-code/).  # noqa: E501

        :param code: The code of this TransactionInfo.  # noqa: E501
        :type code: int
        """

        self._code = code

    @property
    def status(self):
        """Gets the status of this TransactionInfo.  # noqa: E501

        Whether the liveness detection is confirmed `0` or not `1`.  # noqa: E501

        :return: The status of this TransactionInfo.  # noqa: E501
        :rtype: int
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this TransactionInfo.

        Whether the liveness detection is confirmed `0` or not `1`.  # noqa: E501

        :param status: The status of this TransactionInfo.  # noqa: E501
        :type status: int
        """

        self._status = status

    @property
    def tag(self):
        """Gets the tag of this TransactionInfo.  # noqa: E501

        Session identificator, should be unique for each session.  # noqa: E501

        :return: The tag of this TransactionInfo.  # noqa: E501
        :rtype: str
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this TransactionInfo.

        Session identificator, should be unique for each session.  # noqa: E501

        :param tag: The tag of this TransactionInfo.  # noqa: E501
        :type tag: str
        """

        self._tag = tag

    @property
    def transaction_id(self):
        """Gets the transaction_id of this TransactionInfo.  # noqa: E501

        Transaction ID, there can be several transactions within one session.  # noqa: E501

        :return: The transaction_id of this TransactionInfo.  # noqa: E501
        :rtype: str
        """
        return self._transaction_id

    @transaction_id.setter
    def transaction_id(self, transaction_id):
        """Sets the transaction_id of this TransactionInfo.

        Transaction ID, there can be several transactions within one session.  # noqa: E501

        :param transaction_id: The transaction_id of this TransactionInfo.  # noqa: E501
        :type transaction_id: str
        """

        self._transaction_id = transaction_id

    @property
    def video(self):
        """Gets the video of this TransactionInfo.  # noqa: E501

        Link to the session video, depends on the selected storage type. [Learn more](https://docs.regulaforensics.com/develop/face-sdk/web-service/administration/storage/)  # noqa: E501

        :return: The video of this TransactionInfo.  # noqa: E501
        :rtype: str
        """
        return self._video

    @video.setter
    def video(self, video):
        """Sets the video of this TransactionInfo.

        Link to the session video, depends on the selected storage type. [Learn more](https://docs.regulaforensics.com/develop/face-sdk/web-service/administration/storage/)  # noqa: E501

        :param video: The video of this TransactionInfo.  # noqa: E501
        :type video: str
        """

        self._video = video

    @property
    def age(self):
        """Gets the age of this TransactionInfo.  # noqa: E501

        Approximate age with an accuracy of +/-3 years.  # noqa: E501

        :return: The age of this TransactionInfo.  # noqa: E501
        :rtype: [{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]
        """
        return self._age

    @age.setter
    def age(self, age):
        """Sets the age of this TransactionInfo.

        Approximate age with an accuracy of +/-3 years.  # noqa: E501

        :param age: The age of this TransactionInfo.  # noqa: E501
        :type age: [{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]
        """

        self._age = age

    @property
    def portrait(self):
        """Gets the portrait of this TransactionInfo.  # noqa: E501

        Link to the portrait, depends on the selected storage type. [Learn more](https://docs.regulaforensics.com/develop/face-sdk/web-service/administration/storage/)  # noqa: E501

        :return: The portrait of this TransactionInfo.  # noqa: E501
        :rtype: str
        """
        return self._portrait

    @portrait.setter
    def portrait(self, portrait):
        """Sets the portrait of this TransactionInfo.

        Link to the portrait, depends on the selected storage type. [Learn more](https://docs.regulaforensics.com/develop/face-sdk/web-service/administration/storage/)  # noqa: E501

        :param portrait: The portrait of this TransactionInfo.  # noqa: E501
        :type portrait: str
        """

        self._portrait = portrait

    @property
    def metadata(self):
        """Gets the metadata of this TransactionInfo.  # noqa: E501

        A free-form object containing person's extended attributes.  # noqa: E501

        :return: The metadata of this TransactionInfo.  # noqa: E501
        :rtype: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this TransactionInfo.

        A free-form object containing person's extended attributes.  # noqa: E501

        :param metadata: The metadata of this TransactionInfo.  # noqa: E501
        :type metadata: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """

        self._metadata = metadata

    @property
    def type(self):
        """Gets the type of this TransactionInfo.  # noqa: E501


        :return: The type of this TransactionInfo.  # noqa: E501
        :rtype: LivenessType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this TransactionInfo.


        :param type: The type of this TransactionInfo.  # noqa: E501
        :type type: LivenessType
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TransactionInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TransactionInfo):
            return True

        return self.to_dict() != other.to_dict()
